@@ -85,8 +85,8 @@ Plot.PP <- function(PP, titles = NA, xlabel = NA, ylabel = NA, posleg = 2,
   ##### INICIO - Informacoes usadas nos Graficos #####
   
   if (savptc) {
-     cat("\014") # limpa a tela
-     cat("\n\n Salvando graficos em disco. Aguarde o termino!")
+     message("\014") # limpa a tela
+     message("\n\n Salvando graficos em disco. Aguarde o termino!")
   }
   
   if (is.na(xlabel[1]))
@@ -400,7 +400,7 @@ Plot.PP <- function(PP, titles = NA, xlabel = NA, ylabel = NA, posleg = 2,
   if (savptc) { 
      box(col = 'white')
      dev.off() 
-     cat("\n \n Fim!")
+     message("\n \n Fim!")
   }
 
 }
\ No newline at end of file
